===========
NN
===========

We have implemented a couple different neural network models to use for various
tasks. Detailed information can be found in the following pages:

.. toctree::
   :maxdepth: 1

   UNetModel <nn/unet>
   JINetModel <nn/jinet>
